@@ -9,8 +9,11 @@
 #include "../src/consolemodel.h"
 
 #include "clipboard.h"
+#include <QQuickTextDocument>
 #include <QSortFilterProxyModel>
 #include <QStandardItemModel>
+#include <analitzagui/algebrahighlighter.h>
+#include <analitzaplot/plotsfactory.h>
 #include <qqml.h>
 
 using namespace Analitza;
@@ -23,6 +26,38 @@ KAlgebraMobile *KAlgebraMobile::self()
 
 Q_DECLARE_METATYPE(QSharedPointer<Analitza::Variables>)
 
+class AlgebraHighlighterQml : public AlgebraHighlighter
+{
+    Q_OBJECT
+    Q_PROPERTY(QQuickTextDocument *textDocument READ textDocument WRITE setTextDocument NOTIFY textDocumentChanged)
+public:
+    AlgebraHighlighterQml()
+        : AlgebraHighlighter(nullptr)
+    {
+    }
+
+    QQuickTextDocument *textDocument() const
+    {
+        return m_textDocument;
+    }
+    void setTextDocument(QQuickTextDocument *textDocument)
+    {
+        if (textDocument == m_textDocument) {
+            return;
+        }
+
+        m_textDocument = textDocument;
+        setDocument(m_textDocument->textDocument());
+        Q_EMIT textDocumentChanged(textDocument);
+    }
+
+Q_SIGNALS:
+    void textDocumentChanged(QQuickTextDocument *textDocument);
+
+private:
+    QQuickTextDocument *m_textDocument = nullptr;
+};
+
 KAlgebraMobile::KAlgebraMobile(QObject *parent)
     : QObject(parent)
     , m_functionsModel(nullptr)
@@ -36,6 +71,7 @@ KAlgebraMobile::KAlgebraMobile(QObject *parent)
     qmlRegisterType<QSortFilterProxyModel>("org.kde.kalgebra.mobile", 1, 0, "QSortFilterProxyModel");
     qmlRegisterUncreatableType<QAbstractItemModel>("org.kde.kalgebra.mobile", 1, 0, "QAbstractItemModel", QStringLiteral("no"));
     qmlRegisterType<Clipboard>(uri, 1, 0, "Clipboard");
+    qmlRegisterType<AlgebraHighlighterQml>(uri, 1, 0, "AlgebraHighlighter");
 
     qmlRegisterAnonymousType<QStandardItemModel>("Kalgebra", 1);
     qmlRegisterUncreatableType<Analitza::Expression>("org.kde.kalgebra.mobile", 1, 0, "Expression", QStringLiteral("because"));
@@ -87,4 +123,10 @@ QSharedPointer<Analitza::Variables> KAlgebraMobile::variables() const
     return m_vars;
 }
 
+QStringList KAlgebraMobile::examples(Dimension dim) const
+{
+    return PlotsFactory::self()->examples(dim);
+}
+
+#include "kalgebramobile.moc"
 #include "moc_kalgebramobile.cpp"
